@@ -49,14 +49,14 @@ void IdleTest::init()
 {
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
     m_display->createShm();
-    m_seatInterface = m_display->createSeat();
+    m_seatInterface = new SeatInterface(m_display);
     m_seatInterface->setName(QStringLiteral("seat0"));
     m_seatInterface->create();
-    m_idleInterface = m_display->createIdle();
+    m_idleInterface = new IdleInterface(m_display);
 
     // setup connection
     m_connection = new KWayland::Client::ConnectionThread;
@@ -114,10 +114,12 @@ void IdleTest::cleanup()
         m_thread = nullptr;
     }
 
-    CLEANUP(m_idleInterface)
-    CLEANUP(m_seatInterface)
     CLEANUP(m_display)
 #undef CLEANUP
+
+    // these are the children of the display
+    m_idleInterface = nullptr;
+    m_seatInterface = nullptr;
 }
 
 void IdleTest::testTimeout()
