@@ -95,7 +95,7 @@ void TestWindowManagement::init()
     qRegisterMetaType<KWaylandServer::PlasmaWindowManagementInterface::ShowingDesktopState>("ShowingDesktopState");
     delete m_display;
     m_display = new Display(this);
-    m_display->setSocketName(s_socketName);
+    m_display->addSocketName(s_socketName);
     m_display->start();
     QVERIFY(m_display->isRunning());
 
@@ -131,14 +131,12 @@ void TestWindowManagement::init()
     QVERIFY(m_registry->isValid());
     m_registry->setup();
 
-    m_compositorInterface = m_display->createCompositor(m_display);
+    m_compositorInterface = new CompositorInterface(m_display, m_display);
     QVERIFY(compositorSpy.wait());
     m_compositor = m_registry->createCompositor(compositorSpy.first().first().value<quint32>(), compositorSpy.first().last().value<quint32>(), this);
 
 
-    m_windowManagementInterface = m_display->createPlasmaWindowManagement(m_display);
-    m_windowManagementInterface->create();
-    QVERIFY(m_windowManagementInterface->isValid());
+    m_windowManagementInterface = new PlasmaWindowManagementInterface(m_display, m_display);
 
     QVERIFY(windowManagementSpy.wait());
     m_windowManagement = m_registry->createPlasmaWindowManagement(windowManagementSpy.first().first().value<quint32>(), windowManagementSpy.first().last().value<quint32>(), this);
@@ -225,16 +223,15 @@ void TestWindowManagement::cleanup()
     m_connection = nullptr;
 
     m_display->dispatchEvents();
-    delete m_windowManagementInterface;
-    m_windowManagementInterface = nullptr;
-
-    delete m_windowInterface;
-    m_windowInterface = nullptr;
 
     QVERIFY(m_surfaceInterface.isNull());
 
     delete m_display;
     m_display = nullptr;
+
+    // these are the children of the display
+    m_windowManagementInterface = nullptr;
+    m_windowInterface = nullptr;
 }
 
 void TestWindowManagement::testUseAfterUnmap()
