@@ -1,22 +1,8 @@
-/********************************************************************
-Copyright 2020 Aleix Pol Gonzalez <aleixpol@kde.org>
+/*
+    SPDX-FileCopyrightText: 2020 Aleix Pol Gonzalez <aleixpol@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 // Qt
 #include <QHash>
 #include <QThread>
@@ -25,13 +11,14 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "../../src/server/compositor_interface.h"
 #include "../../src/server/display.h"
 #include "../../src/server/seat_interface.h"
-#include "../../src/server/tablet_interface.h"
+#include "../../src/server/tablet_v2_interface.h"
 
 #include "KWayland/Client/compositor.h"
 #include "KWayland/Client/connection_thread.h"
 #include "KWayland/Client/event_queue.h"
 #include "KWayland/Client/registry.h"
 #include "KWayland/Client/seat.h"
+#include "KWayland/Client/surface.h"
 
 #include "qwayland-tablet-unstable-v2.h"
 
@@ -46,6 +33,42 @@ public:
     }
 };
 
+class TabletPad : public QObject, public QtWayland::zwp_tablet_pad_v2
+{
+    Q_OBJECT
+public:
+    TabletPad(::zwp_tablet_pad_v2 *t)
+        : QtWayland::zwp_tablet_pad_v2(t)
+    {
+    }
+
+    void zwp_tablet_pad_v2_done() override {
+        Q_ASSERT(!doneCalled);
+        doneCalled = true;
+    }
+
+    void zwp_tablet_pad_v2_buttons(uint32_t buttons) override {
+        Q_ASSERT(buttons == 1);
+    }
+
+    void zwp_tablet_pad_v2_enter(uint32_t /*serial*/, struct ::zwp_tablet_v2 */*tablet*/, struct ::wl_surface *surface) override {
+        m_currentSurface = surface;
+    }
+
+    void zwp_tablet_pad_v2_button(uint32_t /*time*/, uint32_t button, uint32_t state) override {
+        buttonStates[m_currentSurface][button] = state;
+        Q_EMIT buttonReceived();
+    }
+
+    ::wl_surface *m_currentSurface = nullptr;
+
+    bool doneCalled = false;
+    QHash<::wl_surface *, QHash<uint32_t, uint32_t>> buttonStates;
+
+Q_SIGNALS:
+    void buttonReceived();
+};
+
 class Tool : public QObject, public QtWayland::zwp_tablet_tool_v2
 {
     Q_OBJECT
@@ -90,10 +113,18 @@ public:
         Q_EMIT toolAdded();
     }
 
+    void zwp_tablet_seat_v2_pad_added(struct ::zwp_tablet_pad_v2 *id) override
+    {
+        m_pads << new TabletPad(id);
+        Q_EMIT padAdded();
+    }
+
     QVector<Tablet *> m_tablets;
+    QVector<TabletPad *> m_pads;
     QVector<Tool *> m_tools;
 
 Q_SIGNALS:
+    void padAdded();
     void toolAdded();
     void tabletAdded();
 };
@@ -110,6 +141,7 @@ public:
 private Q_SLOTS:
     void initTestCase();
     void testAdd();
+    void testAddPad();
     void testInteractSimple();
     void testInteractSurfaceChange();
 
@@ -125,10 +157,12 @@ private:
     CompositorInterface *m_serverCompositor;
 
     TabletSeat *m_tabletSeatClient = nullptr;
-    TabletManagerInterface *m_tabletManager;
+    TabletManagerV2Interface *m_tabletManager;
+    QVector<KWayland::Client::Surface *> m_surfacesClient;
 
-    TabletInterface *m_tablet;
-    TabletToolInterface *m_tool;
+    TabletV2Interface *m_tablet;
+    TabletPadV2Interface *m_tabletPad = nullptr;
+    TabletToolV2Interface *m_tool;
 
     QVector<SurfaceInterface *> m_surfaces;
 };
@@ -137,14 +171,14 @@ static const QString s_socketName = QStringLiteral("kwin-wayland-server-tablet-t
 
 void TestTabletInterface::initTestCase()
 {
-    m_display.setSocketName(s_socketName);
+    m_display.addSocketName(s_socketName);
     m_display.start();
     QVERIFY(m_display.isRunning());
 
-    m_seat = m_display.createSeat(this);
+    m_seat = new SeatInterface(&m_display, this);
     m_seat->create();
-    m_serverCompositor = m_display.createCompositor(this);
-    m_tabletManager = m_display.createTabletManagerInterface(this);
+    m_serverCompositor = new CompositorInterface(&m_display, this);
+    m_tabletManager = new TabletManagerV2Interface(&m_display, this);
 
     connect(m_serverCompositor, &CompositorInterface::surfaceCreated, this, [this](SurfaceInterface *surface) {
         m_surfaces += surface;
@@ -192,7 +226,7 @@ void TestTabletInterface::initTestCase()
 
     QSignalSpy surfaceSpy(m_serverCompositor, &CompositorInterface::surfaceCreated);
     for (int i = 0; i < 3; ++i) {
-        m_clientCompositor->createSurface(this);
+        m_surfacesClient += m_clientCompositor->createSurface(this);
     }
     QVERIFY(surfaceSpy.count() < 3 && surfaceSpy.wait(200));
     QVERIFY(m_surfaces.count() == 3);
@@ -218,7 +252,7 @@ TestTabletInterface::~TestTabletInterface()
 
 void TestTabletInterface::testAdd()
 {
-    TabletSeatInterface *seatInterface = m_tabletManager->seat(m_seat);
+    TabletSeatV2Interface *seatInterface = m_tabletManager->seat(m_seat);
     QVERIFY(seatInterface);
 
     QSignalSpy tabletSpy(m_tabletSeatClient, &TabletSeat::tabletAdded);
@@ -228,7 +262,7 @@ void TestTabletInterface::testAdd()
     QCOMPARE(m_tabletSeatClient->m_tablets.count(), 1);
 
     QSignalSpy toolSpy(m_tabletSeatClient, &TabletSeat::toolAdded);
-    m_tool = seatInterface->addTool(KWaylandServer::TabletToolInterface::Pen, 0, 0, {TabletToolInterface::Tilt, TabletToolInterface::Pressure});
+    m_tool = seatInterface->addTool(KWaylandServer::TabletToolV2Interface::Pen, 0, 0, {TabletToolV2Interface::Tilt, TabletToolV2Interface::Pressure});
     QVERIFY(m_tool);
     QVERIFY(toolSpy.wait() || toolSpy.count() == 1);
     QCOMPARE(m_tabletSeatClient->m_tools.count(), 1);
@@ -244,6 +278,32 @@ void TestTabletInterface::testAdd()
     m_tool->setCurrentSurface(nullptr);
 }
 
+void TestTabletInterface::testAddPad()
+{
+    TabletSeatV2Interface *seatInterface = m_tabletManager->seat(m_seat);
+    QVERIFY(seatInterface);
+
+    QSignalSpy tabletPadSpy(m_tabletSeatClient, &TabletSeat::padAdded);
+    m_tabletPad = seatInterface->addTabletPad(QStringLiteral("my tablet pad"), QStringLiteral("tabletpad"), {QStringLiteral("/test/event33")}, 1, 1, 1, 1, 0, m_tablet);
+    QVERIFY(m_tabletPad);
+    QVERIFY(tabletPadSpy.wait() || tabletPadSpy.count() == 1);
+    QCOMPARE(m_tabletSeatClient->m_pads.count(), 1);
+    QVERIFY(m_tabletSeatClient->m_pads[0]);
+
+    QVERIFY(m_tabletPad->ring(0));
+    QVERIFY(m_tabletPad->strip(0));
+
+    QCOMPARE(m_surfaces.count(), 3);
+    QVERIFY(m_tabletSeatClient->m_pads[0]->buttonStates.isEmpty());
+    QSignalSpy buttonSpy(m_tabletSeatClient->m_pads[0], &TabletPad::buttonReceived);
+    m_tabletPad->setCurrentSurface(m_surfaces[0], m_tablet);
+    m_tabletPad->sendButton(123, 0, QtWayland::zwp_tablet_pad_v2::button_state_pressed);
+    QVERIFY(buttonSpy.count() || buttonSpy.wait(100));
+    QCOMPARE(m_tabletSeatClient->m_pads[0]->doneCalled, true);
+    QCOMPARE(m_tabletSeatClient->m_pads[0]->buttonStates.count(), 1);
+    QCOMPARE(m_tabletSeatClient->m_pads[0]->buttonStates[*m_surfacesClient[0]][0], QtWayland::zwp_tablet_pad_v2::button_state_pressed);
+}
+
 static uint s_serial = 0;
 void TestTabletInterface::testInteractSimple()
 {
